[Zorba-coders] [Merge] lp:~zorba-coders/zorba/markos-scratch into lp:zorba

2012-10-02 Thread Markos Zaharioudakis
Markos Zaharioudakis has proposed merging lp:~zorba-coders/zorba/markos-scratch 
into lp:zorba.

Commit message:
fixed memory leak during runtime group-by

Requested reviews:
  Markos Zaharioudakis (markos-za)

For more details, see:
https://code.launchpad.net/~zorba-coders/zorba/markos-scratch/+merge/127433

fixed memory leak during runtime group-by
-- 
https://code.launchpad.net/~zorba-coders/zorba/markos-scratch/+merge/127433
Your team Zorba Coders is subscribed to branch lp:zorba.
=== modified file 'ChangeLog'
--- ChangeLog	2012-10-01 08:15:43 +
+++ ChangeLog	2012-10-02 08:10:31 +
@@ -41,6 +41,7 @@
   * Fixed bug #950621 (Removed two-arg version of fn:parse-xml(); use XML module
 function xml:parse() instead)
   * Fixed bug #867227 (Improved error message for missing commas)
+  * Fixed memory leak during runtime group-by
   * Fixed bug #1024033 and #1023170 (segfaults in parse-xml:parse())
   * Fixed bug #898792 (Dynamically computed strings can now be cast to xs:QName)
   * Fixed bug in determining the IsId property of constructed attribute nodes

=== modified file 'src/runtime/core/flwor_iterator.cpp'
--- src/runtime/core/flwor_iterator.cpp	2012-09-26 05:00:36 +
+++ src/runtime/core/flwor_iterator.cpp	2012-10-02 08:10:31 +
@@ -1456,7 +1456,7 @@
 {
   ZORBA_ASSERT(theGroupByClause);
 
-  GroupTuple* groupTuple = new GroupTuple();
+  std::auto_ptrGroupTuple groupTuple(new GroupTuple());
   std::vectorstore::Item_t groupTupleItems = groupTuple-theItems;
 
   std::vectorGroupingSpec groupSpecs = theGroupByClause-theGroupingSpecs;
@@ -1480,7 +1480,7 @@
   std::vectorstore::TempSeq_t* nongroupVarSequences = 0;
   csize numNonGroupingSpecs = nongroupingSpecs.size();
 
-  if (groupMap-get(groupTuple, nongroupVarSequences))
+  if (groupMap-get(groupTuple.get(), nongroupVarSequences))
   {
 for (csize i = 0; i  numNonGroupingSpecs; ++i)
 {
@@ -1491,8 +1491,6 @@
 
   nongroupingSpecs[i].reset(planState);
 }
-
-delete groupTuple;
   }
   else
   {
@@ -1510,7 +1508,7 @@
   nongroupingSpecs[i].reset(planState);
 }
 
-groupMap-insert(groupTuple, nongroupVarSequences);
+groupMap-insert(groupTuple.release(), nongroupVarSequences);
   }
 }
 

=== modified file 'src/runtime/core/gflwor/groupby_iterator.cpp'
--- src/runtime/core/gflwor/groupby_iterator.cpp	2012-09-26 05:00:36 +
+++ src/runtime/core/gflwor/groupby_iterator.cpp	2012-10-02 08:10:31 +
@@ -356,7 +356,7 @@
 {
   store::Item_t temp;
 
-  GroupTuple* groupTuple = new GroupTuple();
+  std::auto_ptrGroupTuple groupTuple(new GroupTuple());
   std::vectorstore::Item_t groupTupleItems = groupTuple-theItems;
 
   csize numVars = theGroupingSpecs.size();
@@ -383,7 +383,7 @@
 
   std::vectorstore::TempSeq_t* nonGroupTuple = NULL;
 
-  if (groupMap-get(groupTuple, nonGroupTuple)) 
+  if (groupMap-get(groupTuple.get(), nonGroupTuple))
   {
 assert(nonGroupTuple != NULL);
 
@@ -396,8 +396,6 @@
 
   theNonGroupingSpecs[i].theInput-reset(aPlanState);
 }
-
-delete groupTuple;
   }
   else
   {
@@ -416,7 +414,7 @@
   theNonGroupingSpecs[i].theInput-reset(aPlanState);
 }
 
-groupMap-insert(groupTuple, nonGroupTuple);
+groupMap-insert(groupTuple.release(), nonGroupTuple);
   }
 }
 

-- 
Mailing list: https://launchpad.net/~zorba-coders
Post to : zorba-coders@lists.launchpad.net
Unsubscribe : https://launchpad.net/~zorba-coders
More help   : https://help.launchpad.net/ListHelp


Re: [Zorba-coders] [Merge] lp:~zorba-coders/zorba/markos-scratch into lp:zorba

2012-10-02 Thread Markos Zaharioudakis
Review: Approve


-- 
https://code.launchpad.net/~zorba-coders/zorba/markos-scratch/+merge/127433
Your team Zorba Coders is subscribed to branch lp:zorba.

-- 
Mailing list: https://launchpad.net/~zorba-coders
Post to : zorba-coders@lists.launchpad.net
Unsubscribe : https://launchpad.net/~zorba-coders
More help   : https://help.launchpad.net/ListHelp


[Zorba-coders] [Merge] lp:~zorba-coders/zorba/markos-scratch into lp:zorba

2012-10-02 Thread Markos Zaharioudakis
The proposal to merge lp:~zorba-coders/zorba/markos-scratch into lp:zorba has 
been updated.

Status: Needs review = Approved

For more details, see:
https://code.launchpad.net/~zorba-coders/zorba/markos-scratch/+merge/127433
-- 
https://code.launchpad.net/~zorba-coders/zorba/markos-scratch/+merge/127433
Your team Zorba Coders is subscribed to branch lp:zorba.

-- 
Mailing list: https://launchpad.net/~zorba-coders
Post to : zorba-coders@lists.launchpad.net
Unsubscribe : https://launchpad.net/~zorba-coders
More help   : https://help.launchpad.net/ListHelp


[Zorba-coders] [Merge] lp:~zorba-coders/zorba/markos-scratch into lp:zorba

2012-10-02 Thread Zorba Build Bot
Validation queue starting for merge proposal.
Log at: 
http://zorbatest.lambda.nu:8080/remotequeue/markos-scratch-2012-10-02T10-00-52.402Z/log.html
-- 
https://code.launchpad.net/~zorba-coders/zorba/markos-scratch/+merge/127433
Your team Zorba Coders is subscribed to branch lp:zorba.

-- 
Mailing list: https://launchpad.net/~zorba-coders
Post to : zorba-coders@lists.launchpad.net
Unsubscribe : https://launchpad.net/~zorba-coders
More help   : https://help.launchpad.net/ListHelp


[Zorba-coders] [Merge] lp:~zorba-coders/zorba/markos-scratch into lp:zorba

2012-10-02 Thread Zorba Build Bot
Validation queue job markos-scratch-2012-10-02T10-00-52.402Z is finished. The 
final status was:

All tests succeeded!
-- 
https://code.launchpad.net/~zorba-coders/zorba/markos-scratch/+merge/127433
Your team Zorba Coders is subscribed to branch lp:zorba.

-- 
Mailing list: https://launchpad.net/~zorba-coders
Post to : zorba-coders@lists.launchpad.net
Unsubscribe : https://launchpad.net/~zorba-coders
More help   : https://help.launchpad.net/ListHelp


[Zorba-coders] [Merge] lp:~zorba-coders/zorba/markos-scratch into lp:zorba

2012-10-02 Thread noreply
The proposal to merge lp:~zorba-coders/zorba/markos-scratch into lp:zorba has 
been updated.

Status: Approved = Merged

For more details, see:
https://code.launchpad.net/~zorba-coders/zorba/markos-scratch/+merge/127433
-- 
https://code.launchpad.net/~zorba-coders/zorba/markos-scratch/+merge/127433
Your team Zorba Coders is subscribed to branch lp:zorba.

-- 
Mailing list: https://launchpad.net/~zorba-coders
Post to : zorba-coders@lists.launchpad.net
Unsubscribe : https://launchpad.net/~zorba-coders
More help   : https://help.launchpad.net/ListHelp


[Zorba-coders] [Merge] lp:~zorba-coders/zorba/no-copy into lp:zorba

2012-10-02 Thread Zorba Build Bot
Validation queue starting for merge proposal.
Log at: 
http://zorbatest.lambda.nu:8080/remotequeue/no-copy-2012-10-02T10-31-13.875Z/log.html
-- 
https://code.launchpad.net/~zorba-coders/zorba/no-copy/+merge/127281
Your team Zorba Coders is subscribed to branch lp:zorba.

-- 
Mailing list: https://launchpad.net/~zorba-coders
Post to : zorba-coders@lists.launchpad.net
Unsubscribe : https://launchpad.net/~zorba-coders
More help   : https://help.launchpad.net/ListHelp


[Zorba-coders] [Merge] lp:~zorba-coders/zorba/no-copy into lp:zorba

2012-10-02 Thread Zorba Build Bot
Validation queue job no-copy-2012-10-02T10-31-13.875Z is finished. The final 
status was:

All tests succeeded!
-- 
https://code.launchpad.net/~zorba-coders/zorba/no-copy/+merge/127281
Your team Zorba Coders is subscribed to branch lp:zorba.

-- 
Mailing list: https://launchpad.net/~zorba-coders
Post to : zorba-coders@lists.launchpad.net
Unsubscribe : https://launchpad.net/~zorba-coders
More help   : https://help.launchpad.net/ListHelp


[Zorba-coders] [Merge] lp:~zorba-coders/zorba/no-copy into lp:zorba

2012-10-02 Thread noreply
The proposal to merge lp:~zorba-coders/zorba/no-copy into lp:zorba has been 
updated.

Status: Approved = Merged

For more details, see:
https://code.launchpad.net/~zorba-coders/zorba/no-copy/+merge/127281
-- 
https://code.launchpad.net/~zorba-coders/zorba/no-copy/+merge/127281
Your team Zorba Coders is subscribed to branch lp:zorba.

-- 
Mailing list: https://launchpad.net/~zorba-coders
Post to : zorba-coders@lists.launchpad.net
Unsubscribe : https://launchpad.net/~zorba-coders
More help   : https://help.launchpad.net/ListHelp


[Zorba-coders] [Merge] lp:~zorba-coders/zorba/bug-1057792-serialize-nested-xdm-nodes into lp:zorba

2012-10-02 Thread Zorba Build Bot
Validation queue starting for merge proposal.
Log at: 
http://zorbatest.lambda.nu:8080/remotequeue/bug-1057792-serialize-nested-xdm-nodes-2012-10-02T10-57-54.564Z/log.html
-- 
https://code.launchpad.net/~zorba-coders/zorba/bug-1057792-serialize-nested-xdm-nodes/+merge/126833
Your team Zorba Coders is subscribed to branch lp:zorba.

-- 
Mailing list: https://launchpad.net/~zorba-coders
Post to : zorba-coders@lists.launchpad.net
Unsubscribe : https://launchpad.net/~zorba-coders
More help   : https://help.launchpad.net/ListHelp


[Zorba-coders] [Merge] lp:~zorba-coders/zorba/bug-1057792-serialize-nested-xdm-nodes into lp:zorba

2012-10-02 Thread Zorba Build Bot
Validation queue job 
bug-1057792-serialize-nested-xdm-nodes-2012-10-02T10-57-54.564Z is finished. 
The final status was:

All tests succeeded!
-- 
https://code.launchpad.net/~zorba-coders/zorba/bug-1057792-serialize-nested-xdm-nodes/+merge/126833
Your team Zorba Coders is subscribed to branch lp:zorba.

-- 
Mailing list: https://launchpad.net/~zorba-coders
Post to : zorba-coders@lists.launchpad.net
Unsubscribe : https://launchpad.net/~zorba-coders
More help   : https://help.launchpad.net/ListHelp


[Zorba-coders] [Merge] lp:~zorba-coders/zorba/bug-1055608-node-kinds-for-roundtrip into lp:zorba

2012-10-02 Thread Zorba Build Bot
Validation queue starting for merge proposal.
Log at: 
http://zorbatest.lambda.nu:8080/remotequeue/bug-1055608-node-kinds-for-roundtrip-2012-10-02T11-24-30.174Z/log.html
-- 
https://code.launchpad.net/~zorba-coders/zorba/bug-1055608-node-kinds-for-roundtrip/+merge/126590
Your team Zorba Coders is subscribed to branch lp:zorba.

-- 
Mailing list: https://launchpad.net/~zorba-coders
Post to : zorba-coders@lists.launchpad.net
Unsubscribe : https://launchpad.net/~zorba-coders
More help   : https://help.launchpad.net/ListHelp


[Zorba-coders] [Merge] lp:~zorba-coders/zorba/bug-1057792-serialize-nested-xdm-nodes into lp:zorba

2012-10-02 Thread noreply
The proposal to merge 
lp:~zorba-coders/zorba/bug-1057792-serialize-nested-xdm-nodes into lp:zorba has 
been updated.

Status: Approved = Merged

For more details, see:
https://code.launchpad.net/~zorba-coders/zorba/bug-1057792-serialize-nested-xdm-nodes/+merge/126833
-- 
https://code.launchpad.net/~zorba-coders/zorba/bug-1057792-serialize-nested-xdm-nodes/+merge/126833
Your team Zorba Coders is subscribed to branch lp:zorba.

-- 
Mailing list: https://launchpad.net/~zorba-coders
Post to : zorba-coders@lists.launchpad.net
Unsubscribe : https://launchpad.net/~zorba-coders
More help   : https://help.launchpad.net/ListHelp


[Zorba-coders] [Merge] lp:~zorba-coders/zorba/no-copy into lp:zorba

2012-10-02 Thread Markos Zaharioudakis
Markos Zaharioudakis has proposed merging lp:~zorba-coders/zorba/no-copy into 
lp:zorba.

Commit message:
Replaced markForSerialization() method with theIsInUnsafeContext data member.

Requested reviews:
  Markos Zaharioudakis (markos-za)

For more details, see:
https://code.launchpad.net/~zorba-coders/zorba/no-copy/+merge/127465

Replaced markForSerialization() method with theIsInUnsafeContext data member.
-- 
https://code.launchpad.net/~zorba-coders/zorba/no-copy/+merge/127465
Your team Zorba Coders is subscribed to branch lp:zorba.
-- 
Mailing list: https://launchpad.net/~zorba-coders
Post to : zorba-coders@lists.launchpad.net
Unsubscribe : https://launchpad.net/~zorba-coders
More help   : https://help.launchpad.net/ListHelp


[Zorba-coders] [Merge] lp:~zorba-coders/zorba/bug-1055608-node-kinds-for-roundtrip into lp:zorba

2012-10-02 Thread Zorba Build Bot
Validation queue job 
bug-1055608-node-kinds-for-roundtrip-2012-10-02T11-24-30.174Z is finished. The 
final status was:

All tests succeeded!
-- 
https://code.launchpad.net/~zorba-coders/zorba/bug-1055608-node-kinds-for-roundtrip/+merge/126590
Your team Zorba Coders is subscribed to branch lp:zorba.

-- 
Mailing list: https://launchpad.net/~zorba-coders
Post to : zorba-coders@lists.launchpad.net
Unsubscribe : https://launchpad.net/~zorba-coders
More help   : https://help.launchpad.net/ListHelp


[Zorba-coders] [Merge] lp:~zorba-coders/zorba/bug-1055608-node-kinds-for-roundtrip into lp:zorba

2012-10-02 Thread noreply
The proposal to merge 
lp:~zorba-coders/zorba/bug-1055608-node-kinds-for-roundtrip into lp:zorba has 
been updated.

Status: Approved = Merged

For more details, see:
https://code.launchpad.net/~zorba-coders/zorba/bug-1055608-node-kinds-for-roundtrip/+merge/126590
-- 
https://code.launchpad.net/~zorba-coders/zorba/bug-1055608-node-kinds-for-roundtrip/+merge/126590
Your team Zorba Coders is subscribed to branch lp:zorba.

-- 
Mailing list: https://launchpad.net/~zorba-coders
Post to : zorba-coders@lists.launchpad.net
Unsubscribe : https://launchpad.net/~zorba-coders
More help   : https://help.launchpad.net/ListHelp


[Zorba-coders] [Merge] lp:~zorba-coders/zorba/no-copy into lp:zorba

2012-10-02 Thread Markos Zaharioudakis
The proposal to merge lp:~zorba-coders/zorba/no-copy into lp:zorba has been 
updated.

Status: Needs review = Approved

For more details, see:
https://code.launchpad.net/~zorba-coders/zorba/no-copy/+merge/127465
-- 
https://code.launchpad.net/~zorba-coders/zorba/no-copy/+merge/127465
Your team Zorba Coders is subscribed to branch lp:zorba.

-- 
Mailing list: https://launchpad.net/~zorba-coders
Post to : zorba-coders@lists.launchpad.net
Unsubscribe : https://launchpad.net/~zorba-coders
More help   : https://help.launchpad.net/ListHelp


[Zorba-coders] [Merge] lp:~zorba-coders/zorba/no-copy into lp:zorba

2012-10-02 Thread Zorba Build Bot
Validation queue job no-copy-2012-10-02T12-19-48.523Z is finished. The final 
status was:

All tests succeeded!
-- 
https://code.launchpad.net/~zorba-coders/zorba/no-copy/+merge/127465
Your team Zorba Coders is subscribed to branch lp:zorba.

-- 
Mailing list: https://launchpad.net/~zorba-coders
Post to : zorba-coders@lists.launchpad.net
Unsubscribe : https://launchpad.net/~zorba-coders
More help   : https://help.launchpad.net/ListHelp


Re: [Zorba-coders] [Merge] lp:~zorba-coders/zorba/no-copy into lp:zorba

2012-10-02 Thread Zorba Build Bot
Voting does not meet specified criteria. Required: Approve  1, Disapprove  1, 
Needs Fixing  1, Pending  1. Got: 2 Pending.
-- 
https://code.launchpad.net/~zorba-coders/zorba/no-copy/+merge/127465
Your team Zorba Coders is subscribed to branch lp:zorba.

-- 
Mailing list: https://launchpad.net/~zorba-coders
Post to : zorba-coders@lists.launchpad.net
Unsubscribe : https://launchpad.net/~zorba-coders
More help   : https://help.launchpad.net/ListHelp


[Zorba-coders] [Merge] lp:~zorba-coders/zorba/no-copy into lp:zorba

2012-10-02 Thread Zorba Build Bot
The proposal to merge lp:~zorba-coders/zorba/no-copy into lp:zorba has been 
updated.

Status: Approved = Needs review

For more details, see:
https://code.launchpad.net/~zorba-coders/zorba/no-copy/+merge/127465
-- 
https://code.launchpad.net/~zorba-coders/zorba/no-copy/+merge/127465
Your team Zorba Coders is subscribed to branch lp:zorba.

-- 
Mailing list: https://launchpad.net/~zorba-coders
Post to : zorba-coders@lists.launchpad.net
Unsubscribe : https://launchpad.net/~zorba-coders
More help   : https://help.launchpad.net/ListHelp


[Zorba-coders] [Merge] lp:~zorba-coders/zorba/markos-scratch into lp:zorba

2012-10-02 Thread Markos Zaharioudakis
The proposal to merge lp:~zorba-coders/zorba/markos-scratch into lp:zorba has 
been updated.

Status: Needs review = Approved

For more details, see:
https://code.launchpad.net/~zorba-coders/zorba/markos-scratch/+merge/127471
-- 
https://code.launchpad.net/~zorba-coders/zorba/markos-scratch/+merge/127471
Your team Zorba Coders is subscribed to branch lp:zorba.

-- 
Mailing list: https://launchpad.net/~zorba-coders
Post to : zorba-coders@lists.launchpad.net
Unsubscribe : https://launchpad.net/~zorba-coders
More help   : https://help.launchpad.net/ListHelp


[Zorba-coders] [Merge] lp:~zorba-coders/zorba/markos-scratch into lp:zorba

2012-10-02 Thread Zorba Build Bot
Validation queue starting for merge proposal.
Log at: 
http://zorbatest.lambda.nu:8080/remotequeue/markos-scratch-2012-10-02T13-12-53.624Z/log.html
-- 
https://code.launchpad.net/~zorba-coders/zorba/markos-scratch/+merge/127471
Your team Zorba Coders is subscribed to branch lp:zorba.

-- 
Mailing list: https://launchpad.net/~zorba-coders
Post to : zorba-coders@lists.launchpad.net
Unsubscribe : https://launchpad.net/~zorba-coders
More help   : https://help.launchpad.net/ListHelp


Re: [Zorba-coders] [Merge] lp:~zorba-coders/zorba/markos-scratch into lp:zorba

2012-10-02 Thread Zorba Build Bot
The attempt to merge lp:~zorba-coders/zorba/markos-scratch into lp:zorba 
failed. Below is the output from the failed tests.


CMake Error at /home/ceej/zo/testing/zorbatest/tester/TarmacLander.cmake:274 
(message):
  Validation queue job markos-scratch-2012-10-02T13-12-53.624Z is finished.
  The final status was:

  

  2 tests did not succeed - changes not commited.


Error in read script: /home/ceej/zo/testing/zorbatest/tester/TarmacLander.cmake

-- 
https://code.launchpad.net/~zorba-coders/zorba/markos-scratch/+merge/127471
Your team Zorba Coders is subscribed to branch lp:zorba.

-- 
Mailing list: https://launchpad.net/~zorba-coders
Post to : zorba-coders@lists.launchpad.net
Unsubscribe : https://launchpad.net/~zorba-coders
More help   : https://help.launchpad.net/ListHelp


[Zorba-coders] [Merge] lp:~zorba-coders/zorba/markos-scratch into lp:zorba

2012-10-02 Thread Zorba Build Bot
The proposal to merge lp:~zorba-coders/zorba/markos-scratch into lp:zorba has 
been updated.

Status: Approved = Needs review

For more details, see:
https://code.launchpad.net/~zorba-coders/zorba/markos-scratch/+merge/127471
-- 
https://code.launchpad.net/~zorba-coders/zorba/markos-scratch/+merge/127471
Your team Zorba Coders is subscribed to branch lp:zorba.

-- 
Mailing list: https://launchpad.net/~zorba-coders
Post to : zorba-coders@lists.launchpad.net
Unsubscribe : https://launchpad.net/~zorba-coders
More help   : https://help.launchpad.net/ListHelp


[Zorba-coders] [Merge] lp:~zorba-coders/zorba/markos-scratch into lp:zorba

2012-10-02 Thread Markos Zaharioudakis
The proposal to merge lp:~zorba-coders/zorba/markos-scratch into lp:zorba has 
been updated.

Status: Needs review = Approved

For more details, see:
https://code.launchpad.net/~zorba-coders/zorba/markos-scratch/+merge/127471
-- 
https://code.launchpad.net/~zorba-coders/zorba/markos-scratch/+merge/127471
Your team Zorba Coders is subscribed to branch lp:zorba.

-- 
Mailing list: https://launchpad.net/~zorba-coders
Post to : zorba-coders@lists.launchpad.net
Unsubscribe : https://launchpad.net/~zorba-coders
More help   : https://help.launchpad.net/ListHelp


[Zorba-coders] [Merge] lp:~zorba-coders/zorba/markos-scratch into lp:zorba

2012-10-02 Thread Zorba Build Bot
Validation queue starting for merge proposal.
Log at: 
http://zorbatest.lambda.nu:8080/remotequeue/markos-scratch-2012-10-02T14-20-58.42Z/log.html
-- 
https://code.launchpad.net/~zorba-coders/zorba/markos-scratch/+merge/127471
Your team Zorba Coders is subscribed to branch lp:zorba.

-- 
Mailing list: https://launchpad.net/~zorba-coders
Post to : zorba-coders@lists.launchpad.net
Unsubscribe : https://launchpad.net/~zorba-coders
More help   : https://help.launchpad.net/ListHelp


[Zorba-coders] [Merge] lp:~zorba-coders/zorba/fread-pdf-trunk into lp:zorba

2012-10-02 Thread Cezar Andrei
The proposal to merge lp:~zorba-coders/zorba/fread-pdf-trunk into lp:zorba has 
been updated.

Commit Message changed to:

Add read-pdf module for getting text and rendered images from pdf documents.
Make doc comments for createBaser64Binary more explicit on what parameters they 
expect and what they do.
Change, return value to xs_int for getIntValue() method.

For more details, see:
https://code.launchpad.net/~zorba-coders/zorba/fread-pdf-trunk/+merge/126824
-- 
https://code.launchpad.net/~zorba-coders/zorba/fread-pdf-trunk/+merge/126824
Your team Zorba Coders is subscribed to branch lp:zorba.

-- 
Mailing list: https://launchpad.net/~zorba-coders
Post to : zorba-coders@lists.launchpad.net
Unsubscribe : https://launchpad.net/~zorba-coders
More help   : https://help.launchpad.net/ListHelp


[Zorba-coders] [Merge] lp:~zorba-coders/zorba/markos-scratch into lp:zorba

2012-10-02 Thread Zorba Build Bot
Validation queue job markos-scratch-2012-10-02T14-20-58.42Z is finished. The 
final status was:

All tests succeeded!
-- 
https://code.launchpad.net/~zorba-coders/zorba/markos-scratch/+merge/127471
Your team Zorba Coders is subscribed to branch lp:zorba.

-- 
Mailing list: https://launchpad.net/~zorba-coders
Post to : zorba-coders@lists.launchpad.net
Unsubscribe : https://launchpad.net/~zorba-coders
More help   : https://help.launchpad.net/ListHelp


[Zorba-coders] [Merge] lp:~zorba-coders/zorba/markos-scratch into lp:zorba

2012-10-02 Thread noreply
The proposal to merge lp:~zorba-coders/zorba/markos-scratch into lp:zorba has 
been updated.

Status: Approved = Merged

For more details, see:
https://code.launchpad.net/~zorba-coders/zorba/markos-scratch/+merge/127471
-- 
https://code.launchpad.net/~zorba-coders/zorba/markos-scratch/+merge/127471
Your team Zorba Coders is subscribed to branch lp:zorba.

-- 
Mailing list: https://launchpad.net/~zorba-coders
Post to : zorba-coders@lists.launchpad.net
Unsubscribe : https://launchpad.net/~zorba-coders
More help   : https://help.launchpad.net/ListHelp


[Zorba-coders] [Merge] lp:~zorba-coders/zorba/fread-pdf-trunk into lp:zorba

2012-10-02 Thread Cezar Andrei
The proposal to merge lp:~zorba-coders/zorba/fread-pdf-trunk into lp:zorba has 
been updated.

Status: Needs review = Approved

For more details, see:
https://code.launchpad.net/~zorba-coders/zorba/fread-pdf-trunk/+merge/126824
-- 
https://code.launchpad.net/~zorba-coders/zorba/fread-pdf-trunk/+merge/126824
Your team Zorba Coders is subscribed to branch lp:zorba.

-- 
Mailing list: https://launchpad.net/~zorba-coders
Post to : zorba-coders@lists.launchpad.net
Unsubscribe : https://launchpad.net/~zorba-coders
More help   : https://help.launchpad.net/ListHelp


[Zorba-coders] [Merge] lp:~zorba-coders/zorba/fread-pdf-trunk into lp:zorba

2012-10-02 Thread Zorba Build Bot
Validation queue job fread-pdf-trunk-2012-10-02T15-03-54.622Z is finished. The 
final status was:

All tests succeeded!
-- 
https://code.launchpad.net/~zorba-coders/zorba/fread-pdf-trunk/+merge/126824
Your team Zorba Coders is subscribed to branch lp:zorba.

-- 
Mailing list: https://launchpad.net/~zorba-coders
Post to : zorba-coders@lists.launchpad.net
Unsubscribe : https://launchpad.net/~zorba-coders
More help   : https://help.launchpad.net/ListHelp


[Zorba-coders] [Merge] lp:~zorba-coders/zorba/fread-pdf-trunk into lp:zorba

2012-10-02 Thread noreply
The proposal to merge lp:~zorba-coders/zorba/fread-pdf-trunk into lp:zorba has 
been updated.

Status: Approved = Merged

For more details, see:
https://code.launchpad.net/~zorba-coders/zorba/fread-pdf-trunk/+merge/126824
-- 
https://code.launchpad.net/~zorba-coders/zorba/fread-pdf-trunk/+merge/126824
Your team Zorba Coders is subscribed to branch lp:zorba.

-- 
Mailing list: https://launchpad.net/~zorba-coders
Post to : zorba-coders@lists.launchpad.net
Unsubscribe : https://launchpad.net/~zorba-coders
More help   : https://help.launchpad.net/ListHelp


Re: [Zorba-coders] [Merge] lp:~zorba-coders/zorba/excel-doc into lp:zorba/excel-module

2012-10-02 Thread Sorin Marian Nasoi
Review: Approve


-- 
https://code.launchpad.net/~zorba-coders/zorba/excel-doc/+merge/126975
Your team Zorba Coders is subscribed to branch lp:zorba/excel-module.

-- 
Mailing list: https://launchpad.net/~zorba-coders
Post to : zorba-coders@lists.launchpad.net
Unsubscribe : https://launchpad.net/~zorba-coders
More help   : https://help.launchpad.net/ListHelp


[Zorba-coders] [Merge] lp:~zorba-coders/zorba/bug-1056704 into lp:zorba

2012-10-02 Thread Sorin Marian Nasoi
Sorin Marian Nasoi has proposed merging lp:~zorba-coders/zorba/bug-1056704 into 
lp:zorba.

Commit message:
Moved uuid.h to public API.

Requested reviews:
  Juan Zacarias (juan457)
  Sorin Marian Nasoi (sorin.marian.nasoi)
Related bugs:
  Bug #1056704 in Zorba: XQXQ generate UUID bug
  https://bugs.launchpad.net/zorba/+bug/1056704

For more details, see:
https://code.launchpad.net/~zorba-coders/zorba/bug-1056704/+merge/127545

Moved uuid.h to public API.
-- 
https://code.launchpad.net/~zorba-coders/zorba/bug-1056704/+merge/127545
Your team Zorba Coders is subscribed to branch lp:zorba.
=== modified file 'ChangeLog'
--- ChangeLog	2012-10-02 14:58:17 +
+++ ChangeLog	2012-10-02 17:14:40 +
@@ -12,12 +12,11 @@
   * xml:parse (fragment parsing) now allows for a DOCTYPE declaration at the
 beginning of the XML document (requested in bug #1016606).
   * Roundtripping of JSON items has been moved from the serializer to encoding functions.
+  * Added uuid to public API.
   * Best-effort serialization of atomic values in JSON items.
   * Positional pagination support for index probes 
   * Recognize the {http://www.zorba-xquery.com/extensions}no-copy pragma to avoid
 copying nodes before insertion into a collection.
-  * Recognize the no-copy pragma to avoid copying nodes before insertion into
-a collection.
   * Added createUntypedAtomic to API's ItemFactory.
   * new xqDoc feature; reporting collections and indexes
   * new xqDoc function parameter to enable/disable xqDoc generation of certain

=== renamed file 'src/util/uuid.h' = 'include/zorba/util/uuid.h'
--- src/util/uuid.h	2012-09-11 22:55:05 +
+++ include/zorba/util/uuid.h	2012-10-02 17:14:40 +
@@ -21,7 +21,7 @@
 #include algorithm
 #include iostream
 
-#include zorbamisc/config/stdint.h
+#include zorba/config.h
 
 namespace zorba {
 
@@ -43,8 +43,8 @@
  * guarantee that the \c struct fields will be laid out in memory as shown in
  * section 4.1.2. Layout and Byte Order due to possible padding.
  */
-struct uuid {
-  typedef uint8_t value_type;
+struct ZORBA_DLL_PUBLIC uuid {
+  typedef unsigned char value_type;
   typedef value_type reference;
   typedef value_type const const_reference;
   typedef value_type* pointer;
@@ -242,6 +242,7 @@
  * @param u The UUID to emit.
  * @return Returns \a os.
  */
+ZORBA_DLL_PUBLIC
 std::ostream operator( std::ostream os, uuid const u );
 
 ///

=== modified file 'src/api/CMakeLists.txt'
--- src/api/CMakeLists.txt	2012-09-17 00:36:37 +
+++ src/api/CMakeLists.txt	2012-10-02 17:14:40 +
@@ -59,6 +59,7 @@
 auditimpl.cpp
 streambuf.cpp
 transcode_streambuf.cpp
+uuid.cpp
 )
 
 IF (NOT ZORBA_NO_FULL_TEXT)

=== renamed file 'src/util/uuid.cpp' = 'src/api/uuid.cpp'
--- src/util/uuid.cpp	2012-09-17 23:32:33 +
+++ src/api/uuid.cpp	2012-10-02 17:14:40 +
@@ -16,6 +16,7 @@
 
 #include stdafx.h
 #include zorba/config.h
+#include zorba/util/uuid.h
 
 #include cstdio   /* for sprintf(3) */
 
@@ -30,8 +31,6 @@
 # error Unsupported operating system for generating UUIDs
 #endif
 
-#include uuid.h
-
 using namespace std;
 
 namespace zorba {

=== modified file 'src/runtime/random/random_impl.cpp'
--- src/runtime/random/random_impl.cpp	2012-09-17 00:36:37 +
+++ src/runtime/random/random_impl.cpp	2012-10-02 17:14:40 +
@@ -29,7 +29,7 @@
 #include zorba/util/time.h
 #include limits
 
-#include util/uuid.h
+#include zorba/util/uuid.h
 
 namespace zorba {
 

=== modified file 'src/store/naive/simple_store.cpp'
--- src/store/naive/simple_store.cpp	2012-09-18 16:29:31 +
+++ src/store/naive/simple_store.cpp	2012-10-02 17:14:40 +
@@ -32,7 +32,7 @@
 #include diagnostics/diagnostic.h
 #include zorba/diagnostic_list.h
 
-#include util/uuid.h
+#include zorba/util/uuid.h
 #include zorbautils/string_util.h
 
 #ifdef ZORBA_WITH_JSON

=== modified file 'src/unit_tests/test_uuid.cpp'
--- src/unit_tests/test_uuid.cpp	2012-09-06 23:55:13 +
+++ src/unit_tests/test_uuid.cpp	2012-10-02 17:14:40 +
@@ -17,15 +17,13 @@
 #include stdafx.h
 #include iostream
 
-#include util/uuid.h
+#include zorba/util/uuid.h
 
 using namespace std;
 using namespace zorba;
 
 ///
 
-///
-
 namespace zorba {
 namespace UnitTests {
 

=== modified file 'src/util/CMakeLists.txt'
--- src/util/CMakeLists.txt	2012-09-17 00:36:37 +
+++ src/util/CMakeLists.txt	2012-10-02 17:14:40 +
@@ -29,7 +29,6 @@
   unicode_categories.cpp
   uri_util.cpp
   utf8_util.cpp
-  uuid.cpp
   xml_util.cpp
   fx/fxcharheap.cpp
   string/empty_rep_base.cpp

-- 
Mailing list: https://launchpad.net/~zorba-coders
Post to : zorba-coders@lists.launchpad.net
Unsubscribe : https://launchpad.net/~zorba-coders
More help   : https://help.launchpad.net/ListHelp


Re: [Zorba-coders] [Merge] lp:~zorba-coders/zorba/bug-1056704 into lp:zorba

2012-10-02 Thread Sorin Marian Nasoi
Review: Approve


-- 
https://code.launchpad.net/~zorba-coders/zorba/bug-1056704/+merge/127545
Your team Zorba Coders is subscribed to branch lp:zorba.

-- 
Mailing list: https://launchpad.net/~zorba-coders
Post to : zorba-coders@lists.launchpad.net
Unsubscribe : https://launchpad.net/~zorba-coders
More help   : https://help.launchpad.net/ListHelp


Re: [Zorba-coders] [Merge] lp:~zorba-coders/zorba/xqxq-bug-1056704 into lp:zorba/xqxq-module

2012-10-02 Thread Sorin Marian Nasoi
Review: Approve

I have checked these changes in XQXQ together with the changes made by Paul in 
the public API and the reported problem was fixed.

Thanks for the help,
Sorin
-- 
https://code.launchpad.net/~zorba-coders/zorba/xqxq-bug-1056704/+merge/127374
Your team Zorba Coders is subscribed to branch lp:zorba/xqxq-module.

-- 
Mailing list: https://launchpad.net/~zorba-coders
Post to : zorba-coders@lists.launchpad.net
Unsubscribe : https://launchpad.net/~zorba-coders
More help   : https://help.launchpad.net/ListHelp


Re: [Zorba-coders] [Merge] lp:~zorba-coders/zorba/data-converters-module-doc into lp:zorba/data-converters-module

2012-10-02 Thread Sorin Marian Nasoi
Review: Approve

Please note that these changes work only in the new XQDoc generator that is not 
yet merged into the trunk.
-- 
https://code.launchpad.net/~zorba-coders/zorba/data-converters-module-doc/+merge/126951
Your team Zorba Coders is subscribed to branch lp:zorba/data-converters-module.

-- 
Mailing list: https://launchpad.net/~zorba-coders
Post to : zorba-coders@lists.launchpad.net
Unsubscribe : https://launchpad.net/~zorba-coders
More help   : https://help.launchpad.net/ListHelp


Re: [Zorba-coders] [Merge] lp:~zorba-coders/zorba/bug-1056704 into lp:zorba

2012-10-02 Thread Paul J. Lucas
Review: Approve


-- 
https://code.launchpad.net/~zorba-coders/zorba/bug-1056704/+merge/127545
Your team Zorba Coders is subscribed to branch lp:zorba.

-- 
Mailing list: https://launchpad.net/~zorba-coders
Post to : zorba-coders@lists.launchpad.net
Unsubscribe : https://launchpad.net/~zorba-coders
More help   : https://help.launchpad.net/ListHelp


Re: [Zorba-coders] [Merge] lp:~zorba-coders/zorba/email_doc into lp:zorba/email-module

2012-10-02 Thread Sorin Marian Nasoi
Review: Approve

Please note that these changes require the new XQDoc generator to be merged 
into the trunk first.
-- 
https://code.launchpad.net/~zorba-coders/zorba/email_doc/+merge/126942
Your team Zorba Coders is subscribed to branch lp:zorba/email-module.

-- 
Mailing list: https://launchpad.net/~zorba-coders
Post to : zorba-coders@lists.launchpad.net
Unsubscribe : https://launchpad.net/~zorba-coders
More help   : https://help.launchpad.net/ListHelp


[Zorba-coders] [Merge] lp:~zorba-coders/zorba/bug-1056704 into lp:zorba

2012-10-02 Thread Sorin Marian Nasoi
The proposal to merge lp:~zorba-coders/zorba/bug-1056704 into lp:zorba has been 
updated.

Status: Needs review = Approved

For more details, see:
https://code.launchpad.net/~zorba-coders/zorba/bug-1056704/+merge/127545
-- 
https://code.launchpad.net/~zorba-coders/zorba/bug-1056704/+merge/127545
Your team Zorba Coders is subscribed to branch lp:zorba.

-- 
Mailing list: https://launchpad.net/~zorba-coders
Post to : zorba-coders@lists.launchpad.net
Unsubscribe : https://launchpad.net/~zorba-coders
More help   : https://help.launchpad.net/ListHelp


[Zorba-coders] [Merge] lp:~zorba-coders/zorba/bug-1056704 into lp:zorba

2012-10-02 Thread Zorba Build Bot
Validation queue starting for merge proposal.
Log at: 
http://zorbatest.lambda.nu:8080/remotequeue/bug-1056704-2012-10-02T17-29-00.025Z/log.html
-- 
https://code.launchpad.net/~zorba-coders/zorba/bug-1056704/+merge/127545
Your team Zorba Coders is subscribed to branch lp:zorba.

-- 
Mailing list: https://launchpad.net/~zorba-coders
Post to : zorba-coders@lists.launchpad.net
Unsubscribe : https://launchpad.net/~zorba-coders
More help   : https://help.launchpad.net/ListHelp


[Zorba-coders] [Merge] lp:~zorba-coders/zorba/bug-1056704 into lp:zorba

2012-10-02 Thread Zorba Build Bot
The proposal to merge lp:~zorba-coders/zorba/bug-1056704 into lp:zorba has been 
updated.

Status: Approved = Needs review

For more details, see:
https://code.launchpad.net/~zorba-coders/zorba/bug-1056704/+merge/127545
-- 
https://code.launchpad.net/~zorba-coders/zorba/bug-1056704/+merge/127545
Your team Zorba Coders is subscribed to branch lp:zorba.

-- 
Mailing list: https://launchpad.net/~zorba-coders
Post to : zorba-coders@lists.launchpad.net
Unsubscribe : https://launchpad.net/~zorba-coders
More help   : https://help.launchpad.net/ListHelp


Re: [Zorba-coders] [Merge] lp:~zorba-coders/zorba/bug-1056704 into lp:zorba

2012-10-02 Thread Zorba Build Bot
The attempt to merge lp:~zorba-coders/zorba/bug-1056704 into lp:zorba failed. 
Below is the output from the failed tests.


CMake Error at /home/ceej/zo/testing/zorbatest/tester/TarmacLander.cmake:274 
(message):
  Validation queue job bug-1056704-2012-10-02T17-29-00.025Z is finished.  The
  final status was:

  

  1 tests did not succeed - changes not commited.


Error in read script: /home/ceej/zo/testing/zorbatest/tester/TarmacLander.cmake

-- 
https://code.launchpad.net/~zorba-coders/zorba/bug-1056704/+merge/127545
Your team Zorba Coders is subscribed to branch lp:zorba.

-- 
Mailing list: https://launchpad.net/~zorba-coders
Post to : zorba-coders@lists.launchpad.net
Unsubscribe : https://launchpad.net/~zorba-coders
More help   : https://help.launchpad.net/ListHelp


[Zorba-coders] [Merge] lp:~zorba-coders/zorba/bug-1056704 into lp:zorba

2012-10-02 Thread Zorba Build Bot
Validation queue starting for merge proposal.
Log at: 
http://zorbatest.lambda.nu:8080/remotequeue/bug-1056704-2012-10-02T17-55-53.218Z/log.html
-- 
https://code.launchpad.net/~zorba-coders/zorba/bug-1056704/+merge/127545
Your team Zorba Coders is subscribed to branch lp:zorba.

-- 
Mailing list: https://launchpad.net/~zorba-coders
Post to : zorba-coders@lists.launchpad.net
Unsubscribe : https://launchpad.net/~zorba-coders
More help   : https://help.launchpad.net/ListHelp


[Zorba-coders] [Merge] lp:~zorba-coders/zorba/bug-1056704 into lp:zorba

2012-10-02 Thread Sorin Marian Nasoi
The proposal to merge lp:~zorba-coders/zorba/bug-1056704 into lp:zorba has been 
updated.

Status: Needs review = Approved

For more details, see:
https://code.launchpad.net/~zorba-coders/zorba/bug-1056704/+merge/127545
-- 
https://code.launchpad.net/~zorba-coders/zorba/bug-1056704/+merge/127545
Your team Zorba Coders is subscribed to branch lp:zorba.

-- 
Mailing list: https://launchpad.net/~zorba-coders
Post to : zorba-coders@lists.launchpad.net
Unsubscribe : https://launchpad.net/~zorba-coders
More help   : https://help.launchpad.net/ListHelp


[Zorba-coders] [Merge] lp:~zorba-coders/zorba/bug-1056704 into lp:zorba

2012-10-02 Thread Zorba Build Bot
Validation queue job bug-1056704-2012-10-02T17-55-53.218Z is finished. The 
final status was:

All tests succeeded!
-- 
https://code.launchpad.net/~zorba-coders/zorba/bug-1056704/+merge/127545
Your team Zorba Coders is subscribed to branch lp:zorba.

-- 
Mailing list: https://launchpad.net/~zorba-coders
Post to : zorba-coders@lists.launchpad.net
Unsubscribe : https://launchpad.net/~zorba-coders
More help   : https://help.launchpad.net/ListHelp


Re: [Zorba-coders] [Merge] lp:~zorba-coders/zorba/bug-1056704 into lp:zorba

2012-10-02 Thread Zorba Build Bot
Voting does not meet specified criteria. Required: Approve  1, Disapprove  1, 
Needs Fixing  1, Pending  1. Got: 2 Approve, 1 Pending.
-- 
https://code.launchpad.net/~zorba-coders/zorba/bug-1056704/+merge/127545
Your team Zorba Coders is subscribed to branch lp:zorba.

-- 
Mailing list: https://launchpad.net/~zorba-coders
Post to : zorba-coders@lists.launchpad.net
Unsubscribe : https://launchpad.net/~zorba-coders
More help   : https://help.launchpad.net/ListHelp


[Zorba-coders] [Merge] lp:~zorba-coders/zorba/bug-1056704 into lp:zorba

2012-10-02 Thread Zorba Build Bot
The proposal to merge lp:~zorba-coders/zorba/bug-1056704 into lp:zorba has been 
updated.

Status: Approved = Needs review

For more details, see:
https://code.launchpad.net/~zorba-coders/zorba/bug-1056704/+merge/127545
-- 
https://code.launchpad.net/~zorba-coders/zorba/bug-1056704/+merge/127545
Your team Zorba Coders is subscribed to branch lp:zorba.

-- 
Mailing list: https://launchpad.net/~zorba-coders
Post to : zorba-coders@lists.launchpad.net
Unsubscribe : https://launchpad.net/~zorba-coders
More help   : https://help.launchpad.net/ListHelp


Re: [Zorba-coders] [Merge] lp:~zorba-coders/zorba/no-copy into lp:zorba

2012-10-02 Thread Markos Zaharioudakis
Review: Approve


-- 
https://code.launchpad.net/~zorba-coders/zorba/no-copy/+merge/127465
Your team Zorba Coders is subscribed to branch lp:zorba.

-- 
Mailing list: https://launchpad.net/~zorba-coders
Post to : zorba-coders@lists.launchpad.net
Unsubscribe : https://launchpad.net/~zorba-coders
More help   : https://help.launchpad.net/ListHelp


[Zorba-coders] [Merge] lp:~zorba-coders/zorba/no-copy into lp:zorba

2012-10-02 Thread Markos Zaharioudakis
The proposal to merge lp:~zorba-coders/zorba/no-copy into lp:zorba has been 
updated.

Status: Needs review = Approved

For more details, see:
https://code.launchpad.net/~zorba-coders/zorba/no-copy/+merge/127465
-- 
https://code.launchpad.net/~zorba-coders/zorba/no-copy/+merge/127465
Your team Zorba Coders is subscribed to branch lp:zorba.

-- 
Mailing list: https://launchpad.net/~zorba-coders
Post to : zorba-coders@lists.launchpad.net
Unsubscribe : https://launchpad.net/~zorba-coders
More help   : https://help.launchpad.net/ListHelp


[Zorba-coders] [Merge] lp:~zorba-coders/zorba/no-copy into lp:zorba

2012-10-02 Thread Zorba Build Bot
Validation queue starting for merge proposal.
Log at: 
http://zorbatest.lambda.nu:8080/remotequeue/no-copy-2012-10-02T19-34-40.094Z/log.html
-- 
https://code.launchpad.net/~zorba-coders/zorba/no-copy/+merge/127465
Your team Zorba Coders is subscribed to branch lp:zorba.

-- 
Mailing list: https://launchpad.net/~zorba-coders
Post to : zorba-coders@lists.launchpad.net
Unsubscribe : https://launchpad.net/~zorba-coders
More help   : https://help.launchpad.net/ListHelp


[Zorba-coders] [Merge] lp:~zorba-coders/zorba/no-copy into lp:zorba

2012-10-02 Thread Zorba Build Bot
Validation queue job no-copy-2012-10-02T19-34-40.094Z is finished. The final 
status was:

All tests succeeded!
-- 
https://code.launchpad.net/~zorba-coders/zorba/no-copy/+merge/127465
Your team Zorba Coders is subscribed to branch lp:zorba.

-- 
Mailing list: https://launchpad.net/~zorba-coders
Post to : zorba-coders@lists.launchpad.net
Unsubscribe : https://launchpad.net/~zorba-coders
More help   : https://help.launchpad.net/ListHelp


[Zorba-coders] [Merge] lp:~zorba-coders/zorba/no-copy into lp:zorba

2012-10-02 Thread noreply
The proposal to merge lp:~zorba-coders/zorba/no-copy into lp:zorba has been 
updated.

Status: Approved = Merged

For more details, see:
https://code.launchpad.net/~zorba-coders/zorba/no-copy/+merge/127465
-- 
https://code.launchpad.net/~zorba-coders/zorba/no-copy/+merge/127465
Your team Zorba Coders is subscribed to branch lp:zorba.

-- 
Mailing list: https://launchpad.net/~zorba-coders
Post to : zorba-coders@lists.launchpad.net
Unsubscribe : https://launchpad.net/~zorba-coders
More help   : https://help.launchpad.net/ListHelp


Re: [Zorba-coders] [Merge] lp:~zorba-coders/zorba/bug-1056704 into lp:zorba

2012-10-02 Thread Juan Zacarias
Review: Approve


-- 
https://code.launchpad.net/~zorba-coders/zorba/bug-1056704/+merge/127545
Your team Zorba Coders is subscribed to branch lp:zorba.

-- 
Mailing list: https://launchpad.net/~zorba-coders
Post to : zorba-coders@lists.launchpad.net
Unsubscribe : https://launchpad.net/~zorba-coders
More help   : https://help.launchpad.net/ListHelp


Re: [Zorba-coders] [Merge] lp:~zorba-coders/zorba/xqxq-bug-1056704 into lp:zorba/xqxq-module

2012-10-02 Thread Juan Zacarias
Review: Approve


-- 
https://code.launchpad.net/~zorba-coders/zorba/xqxq-bug-1056704/+merge/127374
Your team Zorba Coders is subscribed to branch lp:zorba/xqxq-module.

-- 
Mailing list: https://launchpad.net/~zorba-coders
Post to : zorba-coders@lists.launchpad.net
Unsubscribe : https://launchpad.net/~zorba-coders
More help   : https://help.launchpad.net/ListHelp


[Zorba-coders] [Merge] lp:~zorba-coders/zorba/bug-1056704 into lp:zorba

2012-10-02 Thread Sorin Marian Nasoi
The proposal to merge lp:~zorba-coders/zorba/bug-1056704 into lp:zorba has been 
updated.

Status: Needs review = Approved

For more details, see:
https://code.launchpad.net/~zorba-coders/zorba/bug-1056704/+merge/127545
-- 
https://code.launchpad.net/~zorba-coders/zorba/bug-1056704/+merge/127545
Your team Zorba Coders is subscribed to branch lp:zorba.

-- 
Mailing list: https://launchpad.net/~zorba-coders
Post to : zorba-coders@lists.launchpad.net
Unsubscribe : https://launchpad.net/~zorba-coders
More help   : https://help.launchpad.net/ListHelp


[Zorba-coders] [Merge] lp:~zorba-coders/zorba/bug-1056704 into lp:zorba

2012-10-02 Thread Zorba Build Bot
Validation queue starting for merge proposal.
Log at: 
http://zorbatest.lambda.nu:8080/remotequeue/bug-1056704-2012-10-02T20-35-50.243Z/log.html
-- 
https://code.launchpad.net/~zorba-coders/zorba/bug-1056704/+merge/127545
Your team Zorba Coders is subscribed to branch lp:zorba.

-- 
Mailing list: https://launchpad.net/~zorba-coders
Post to : zorba-coders@lists.launchpad.net
Unsubscribe : https://launchpad.net/~zorba-coders
More help   : https://help.launchpad.net/ListHelp


[Zorba-coders] [Merge] lp:~zorba-coders/zorba/bug-1056704 into lp:zorba

2012-10-02 Thread Zorba Build Bot
Validation queue job bug-1056704-2012-10-02T20-35-50.243Z is finished. The 
final status was:

All tests succeeded!
-- 
https://code.launchpad.net/~zorba-coders/zorba/bug-1056704/+merge/127545
Your team Zorba Coders is subscribed to branch lp:zorba.

-- 
Mailing list: https://launchpad.net/~zorba-coders
Post to : zorba-coders@lists.launchpad.net
Unsubscribe : https://launchpad.net/~zorba-coders
More help   : https://help.launchpad.net/ListHelp


[Zorba-coders] [Merge] lp:~zorba-coders/zorba/bug-1056704 into lp:zorba

2012-10-02 Thread noreply
The proposal to merge lp:~zorba-coders/zorba/bug-1056704 into lp:zorba has been 
updated.

Status: Approved = Merged

For more details, see:
https://code.launchpad.net/~zorba-coders/zorba/bug-1056704/+merge/127545
-- 
https://code.launchpad.net/~zorba-coders/zorba/bug-1056704/+merge/127545
Your team Zorba Coders is subscribed to branch lp:zorba.

-- 
Mailing list: https://launchpad.net/~zorba-coders
Post to : zorba-coders@lists.launchpad.net
Unsubscribe : https://launchpad.net/~zorba-coders
More help   : https://help.launchpad.net/ListHelp


[Zorba-coders] [Merge] lp:~zorba-coders/zorba/xqxq-bug-1056704 into lp:zorba/xqxq-module

2012-10-02 Thread Sorin Marian Nasoi
The proposal to merge lp:~zorba-coders/zorba/xqxq-bug-1056704 into 
lp:zorba/xqxq-module has been updated.

Status: Needs review = Approved

For more details, see:
https://code.launchpad.net/~zorba-coders/zorba/xqxq-bug-1056704/+merge/127374
-- 
https://code.launchpad.net/~zorba-coders/zorba/xqxq-bug-1056704/+merge/127374
Your team Zorba Coders is subscribed to branch lp:zorba/xqxq-module.

-- 
Mailing list: https://launchpad.net/~zorba-coders
Post to : zorba-coders@lists.launchpad.net
Unsubscribe : https://launchpad.net/~zorba-coders
More help   : https://help.launchpad.net/ListHelp


Re: [Zorba-coders] [Merge] lp:~zorba-coders/zorba/xqxq-bug-1056704 into lp:zorba/xqxq-module

2012-10-02 Thread Zorba Build Bot
No proposals found for merge of lp:~zorba-coders/zorba/bug-1056704 into 
lp:zorba/xqxq-module.
-- 
https://code.launchpad.net/~zorba-coders/zorba/xqxq-bug-1056704/+merge/127374
Your team Zorba Coders is subscribed to branch lp:zorba/xqxq-module.

-- 
Mailing list: https://launchpad.net/~zorba-coders
Post to : zorba-coders@lists.launchpad.net
Unsubscribe : https://launchpad.net/~zorba-coders
More help   : https://help.launchpad.net/ListHelp


[Zorba-coders] [Merge] lp:~zorba-coders/zorba/xqxq-bug-1056704 into lp:zorba/xqxq-module

2012-10-02 Thread Zorba Build Bot
The proposal to merge lp:~zorba-coders/zorba/xqxq-bug-1056704 into 
lp:zorba/xqxq-module has been updated.

Status: Approved = Needs review

For more details, see:
https://code.launchpad.net/~zorba-coders/zorba/xqxq-bug-1056704/+merge/127374
-- 
https://code.launchpad.net/~zorba-coders/zorba/xqxq-bug-1056704/+merge/127374
Your team Zorba Coders is subscribed to branch lp:zorba/xqxq-module.

-- 
Mailing list: https://launchpad.net/~zorba-coders
Post to : zorba-coders@lists.launchpad.net
Unsubscribe : https://launchpad.net/~zorba-coders
More help   : https://help.launchpad.net/ListHelp


[Zorba-coders] [Merge] lp:~zorba-coders/zorba/xqxq-bug-1056704 into lp:zorba/xqxq-module

2012-10-02 Thread Sorin Marian Nasoi
Sorin Marian Nasoi has proposed merging lp:~zorba-coders/zorba/xqxq-bug-1056704 
into lp:zorba/xqxq-module.

Requested reviews:
  Sorin Marian Nasoi (sorin.marian.nasoi)
  Juan Zacarias (juan457)
Related bugs:
  Bug #1056704 in Zorba: XQXQ generate UUID bug
  https://bugs.launchpad.net/zorba/+bug/1056704

For more details, see:
https://code.launchpad.net/~zorba-coders/zorba/xqxq-bug-1056704/+merge/127594

Replaced xqxq's implementation of uuid for zorba's implementation in 
zorba/util/uuid.h
-- 
https://code.launchpad.net/~zorba-coders/zorba/xqxq-bug-1056704/+merge/127594
Your team Zorba Coders is subscribed to branch lp:zorba/xqxq-module.
=== modified file 'src/xqxq.xq.src/xqxq.cpp'
--- src/xqxq.xq.src/xqxq.cpp	2011-11-30 21:57:52 +
+++ src/xqxq.xq.src/xqxq.cpp	2012-10-02 21:11:22 +
@@ -10,7 +10,7 @@
 #include zorba/xquery.h
 #include time.h
 #include stdio.h
-
+#include zorba/util/uuid.h
 #include vector
 
 #include xqxq.h
@@ -269,29 +269,18 @@
   e.diagnostic().qname().ns(), e.diagnostic().qname().localname());
   throw USER_EXCEPTION(errQName, err.str());
 }
-
-String lUUID = getUUID();
-
-lQueryMap-storeQuery(lUUID, lQuery);
-
-return ItemSequence_t(new SingletonItemSequence(XQXQModule::getItemFactory()-createAnyURI(lUUID)));
-  }
-
-  String 
-PrepareMainModuleFunction::S4 ()
-  {
-unsigned long randNum = (1 + rand() * 0x1)|0;
-char* randBuff= new char[20];
-sprintf(randBuff, %lx, randNum);
-String lString(randBuff);
-delete[] randBuff;
-return lString;
-  }
-
-  String 
-PrepareMainModuleFunction::getUUID()
-  {
-return (String(urn:uuid:) + S4()+-+S4()+-+S4()+-+S4()+-+S4()+S4());
+
+uuid lUUID;
+uuid::create(lUUID);
+
+std::stringstream lStream;
+lStream  lUUID;
+
+String lStrUUID = lStream.str();
+
+lQueryMap-storeQuery(lStrUUID, lQuery);
+
+return ItemSequence_t(new SingletonItemSequence(XQXQModule::getItemFactory()-createAnyURI(lStrUUID)));
   }
 
   /***

=== modified file 'src/xqxq.xq.src/xqxq.h'
--- src/xqxq.xq.src/xqxq.h	2011-11-28 23:55:59 +
+++ src/xqxq.xq.src/xqxq.h	2012-10-02 21:11:22 +
@@ -126,14 +126,6 @@
 evaluate(const Arguments_t,
  const zorba::StaticContext*,
  const zorba::DynamicContext*) const;
-
-protected:
-   static String
- getUUID();
-
-   static String
- S4();
-
   };
 
   class PrepareLibraryModuleFunction : public XQXQFunction{

-- 
Mailing list: https://launchpad.net/~zorba-coders
Post to : zorba-coders@lists.launchpad.net
Unsubscribe : https://launchpad.net/~zorba-coders
More help   : https://help.launchpad.net/ListHelp


Re: [Zorba-coders] [Merge] lp:~zorba-coders/zorba/xqxq-bug-1056704 into lp:zorba/xqxq-module

2012-10-02 Thread Sorin Marian Nasoi
Review: Approve

Resubmitted merge proposal.
-- 
https://code.launchpad.net/~zorba-coders/zorba/xqxq-bug-1056704/+merge/127594
Your team Zorba Coders is subscribed to branch lp:zorba/xqxq-module.

-- 
Mailing list: https://launchpad.net/~zorba-coders
Post to : zorba-coders@lists.launchpad.net
Unsubscribe : https://launchpad.net/~zorba-coders
More help   : https://help.launchpad.net/ListHelp


Re: [Zorba-coders] [Merge] lp:~zorba-coders/zorba/xpath_doc into lp:zorba

2012-10-02 Thread Sorin Marian Nasoi
Review: Needs Fixing

This depends on branch lp:~zorba-coders/zorba/new-xqdoc being merged into the 
trunk.

Without the above mentioned branch, one can not see the changes with the 
current XQDoc generator because the documentation for the xpath_functions.xq 
module is not generated every time make doc/xqdoc is run.

For details please see 
http://bazaar.launchpad.net/~zorba-coders/zorba/trunk/view/head:/modules/com/zorba-xquery/www/modules/xqdoc2xhtml/index.xq
line 530.
-- 
https://code.launchpad.net/~zorba-coders/zorba/xpath_doc/+merge/126681
Your team Zorba Coders is subscribed to branch lp:zorba.

-- 
Mailing list: https://launchpad.net/~zorba-coders
Post to : zorba-coders@lists.launchpad.net
Unsubscribe : https://launchpad.net/~zorba-coders
More help   : https://help.launchpad.net/ListHelp


[Zorba-coders] [Merge] lp:~zorba-coders/zorba/no-copy into lp:zorba

2012-10-02 Thread Markos Zaharioudakis
Markos Zaharioudakis has proposed merging lp:~zorba-coders/zorba/no-copy into 
lp:zorba.

Commit message:
1. Put back markForSerialization() (renamed as markInUsafeContext())
2. path expr is unsafe if it contains any KindTest with type check and the 
construction mode i strip
3. copying is unsafe only if ns_inherit and ns_preserve


Requested reviews:
  Markos Zaharioudakis (markos-za)

For more details, see:
https://code.launchpad.net/~zorba-coders/zorba/no-copy/+merge/127604

1. Put back markForSerialization() (renamed as markInUsafeContext())
2. path expr is unsafe if it contains any KindTest with type check and the 
construction mode i strip
3. copying is unsafe only if ns_inherit and ns_preserve
-- 
https://code.launchpad.net/~zorba-coders/zorba/no-copy/+merge/127604
Your team Zorba Coders is subscribed to branch lp:zorba.
=== modified file 'src/compiler/expression/expr_base.cpp'
--- src/compiler/expression/expr_base.cpp	2012-10-02 11:57:15 +
+++ src/compiler/expression/expr_base.cpp	2012-10-02 22:18:11 +
@@ -541,6 +541,30 @@
 /***
 
 /
+BoolAnnotationValue expr::getInUnsafeContext() const
+{
+  return (BoolAnnotationValue)
+ ((theFlags1  IN_UNSAFE_CONTEXT_MASK)  IN_UNSAFE_CONTEXT);
+}
+
+
+void expr::setInUnsafeContext(BoolAnnotationValue v)
+{
+  theFlags1 = ~IN_UNSAFE_CONTEXT_MASK;
+  theFlags1 |= (v  IN_UNSAFE_CONTEXT);
+}
+
+
+bool expr::inUnsafeContext() const
+{
+  BoolAnnotationValue v = getInUnsafeContext();
+  return (v == ANNOTATION_TRUE || v == ANNOTATION_TRUE_FIXED);
+}
+
+
+/***
+
+/
 BoolAnnotationValue expr::getContainsPragma() const
 {
   return (BoolAnnotationValue)

=== modified file 'src/compiler/expression/expr_base.h'
--- src/compiler/expression/expr_base.h	2012-10-02 11:57:15 +
+++ src/compiler/expression/expr_base.h	2012-10-02 22:18:11 +
@@ -147,8 +147,9 @@
 UNFOLDABLE  = 10,
 CONTAINS_RECURSIVE_CALL = 12,
 PROPAGATES_INPUT_NODES  = 14,
-MUST_COPY_NODES = 16,
-CONTAINS_PRAGMA = 18
+IN_UNSAFE_CONTEXT   = 16,
+MUST_COPY_NODES = 18,
+CONTAINS_PRAGMA = 20
   } Annotationkey;
 
   typedef enum
@@ -161,8 +162,9 @@
 UNFOLDABLE_MASK   = 0xC00,
 CONTAINS_RECURSIVE_CALL_MASK  = 0x3000,
 PROPAGATES_INPUT_NODES_MASK   = 0xC000,
-MUST_COPY_NODES_MASK  = 0x3,
-CONTAINS_PRAGMA_MASK  = 0xC
+IN_UNSAFE_CONTEXT_MASK= 0x3,
+MUST_COPY_NODES_MASK  = 0xC,
+CONTAINS_PRAGMA_MASK  = 0x30
   } AnnotationMask;
 
 
@@ -313,6 +315,13 @@
 
   void setMustCopyNodes(BoolAnnotationValue v);
 
+  // Annotation : inUnsafeContext
+  BoolAnnotationValue getInUnsafeContext() const;
+
+  void setInUnsafeContext(BoolAnnotationValue v);
+
+  bool inUnsafeContext() const;
+
   // Annotation : containsPragma
   BoolAnnotationValue getContainsPragma() const;
 

=== modified file 'src/compiler/rewriter/rules/nodeid_rules.cpp'
--- src/compiler/rewriter/rules/nodeid_rules.cpp	2012-10-02 11:57:15 +
+++ src/compiler/rewriter/rules/nodeid_rules.cpp	2012-10-02 22:18:11 +
@@ -600,11 +600,11 @@
   // inherited from the referencing tree if N had been copied into that
   // tree. (On the other hand it is ok if the query result contains nodes
   // which are not shared but have shared descendants). To handle this,
   // we set theIsInUnsafeContext so that any exprs that (a) extract nodes
   // out of input nodes and (b) may propagate the extracted nodes to the
   // query result will be considered as unsafe and thus require that 
   // their input trees are standalone.
-  theIsInUnsafeContext = true;
+  markInUnsafeContext(node);
 }
   }
   else
@@ -652,25 +652,11 @@
 expr* node,
 UDFCallChain udfCaller)
 {
-  TypeManager* tm = node-get_type_manager();
-  RootTypeManager rtm = GENV_TYPESYSTEM;
-
-  bool savedIsInUnsafeContext = theIsInUnsafeContext;
-
-  if (theIsInUnsafeContext)
-  {
-xqtref_t retType = node-get_return_type();
-
-if (TypeOps::is_subtype(tm, *retType, *rtm.ANY_ATOMIC_TYPE_STAR))
-  theIsInUnsafeContext = false;
-  }
-
   switch (node-get_expr_kind())
   {
   case const_expr_kind:
   case var_expr_kind:
   {
-theIsInUnsafeContext = savedIsInUnsafeContext;
 return;
   }
 
@@ -692,7 +678,8 @@
 
 static_context* sctx = e-get_sctx();
 
-if (sctx-preserve_mode() != StaticContextConsts::no_preserve_ns)
+if (sctx-preserve_mode() == StaticContextConsts::preserve_ns 
+sctx-inherit_mode() == 
@@ -600,11 +600,11 @@
   // tree. (On the other hand it is ok if the query result contains nodes
   // which are not shared but have shared descendants). To handle this,
-  // we set theIsInUnsafeContext so that any exprs that (a) extract nodes
+  // we call markInUnsafeContext() so that any exprs that (a) extract nodes
   // out of input nodes and (b) may propagate the extracted nodes to the
   // query result will be considered as unsafe and thus require that 

Re: [Zorba-coders] [Merge] lp:~zorba-coders/zorba/xqxq-bug-1056704 into lp:zorba/xqxq-module

2012-10-02 Thread Juan Zacarias
Review: Approve


-- 
https://code.launchpad.net/~zorba-coders/zorba/xqxq-bug-1056704/+merge/127594
Your team Zorba Coders is subscribed to branch lp:zorba/xqxq-module.

-- 
Mailing list: https://launchpad.net/~zorba-coders
Post to : zorba-coders@lists.launchpad.net
Unsubscribe : https://launchpad.net/~zorba-coders
More help   : https://help.launchpad.net/ListHelp


Re: [Zorba-coders] [Merge] lp:~zorba-coders/zorba/no-copy into lp:zorba

2012-10-02 Thread Markos Zaharioudakis
Review: Approve


-- 
https://code.launchpad.net/~zorba-coders/zorba/no-copy/+merge/127604
Your team Zorba Coders is subscribed to branch lp:zorba.

-- 
Mailing list: https://launchpad.net/~zorba-coders
Post to : zorba-coders@lists.launchpad.net
Unsubscribe : https://launchpad.net/~zorba-coders
More help   : https://help.launchpad.net/ListHelp


[Zorba-coders] [Merge] lp:~zorba-coders/zorba/no-copy into lp:zorba

2012-10-02 Thread Markos Zaharioudakis
The proposal to merge lp:~zorba-coders/zorba/no-copy into lp:zorba has been 
updated.

Status: Needs review = Approved

For more details, see:
https://code.launchpad.net/~zorba-coders/zorba/no-copy/+merge/127604
-- 
https://code.launchpad.net/~zorba-coders/zorba/no-copy/+merge/127604
Your team Zorba Coders is subscribed to branch lp:zorba.

-- 
Mailing list: https://launchpad.net/~zorba-coders
Post to : zorba-coders@lists.launchpad.net
Unsubscribe : https://launchpad.net/~zorba-coders
More help   : https://help.launchpad.net/ListHelp


[Zorba-coders] [Merge] lp:~zorba-coders/zorba/no-copy into lp:zorba

2012-10-02 Thread Zorba Build Bot
Validation queue starting for merge proposal.
Log at: 
http://zorbatest.lambda.nu:8080/remotequeue/no-copy-2012-10-02T22-59-53.733Z/log.html
-- 
https://code.launchpad.net/~zorba-coders/zorba/no-copy/+merge/127604
Your team Zorba Coders is subscribed to branch lp:zorba.

-- 
Mailing list: https://launchpad.net/~zorba-coders
Post to : zorba-coders@lists.launchpad.net
Unsubscribe : https://launchpad.net/~zorba-coders
More help   : https://help.launchpad.net/ListHelp


[Zorba-coders] [Merge] lp:~zorba-coders/zorba/no-copy into lp:zorba

2012-10-02 Thread Zorba Build Bot
Validation queue job no-copy-2012-10-02T22-59-53.733Z is finished. The final 
status was:

All tests succeeded!
-- 
https://code.launchpad.net/~zorba-coders/zorba/no-copy/+merge/127604
Your team Zorba Coders is subscribed to branch lp:zorba.

-- 
Mailing list: https://launchpad.net/~zorba-coders
Post to : zorba-coders@lists.launchpad.net
Unsubscribe : https://launchpad.net/~zorba-coders
More help   : https://help.launchpad.net/ListHelp


[Zorba-coders] [Merge] lp:~zorba-coders/zorba/no-copy into lp:zorba

2012-10-02 Thread noreply
The proposal to merge lp:~zorba-coders/zorba/no-copy into lp:zorba has been 
updated.

Status: Approved = Merged

For more details, see:
https://code.launchpad.net/~zorba-coders/zorba/no-copy/+merge/127604
-- 
https://code.launchpad.net/~zorba-coders/zorba/no-copy/+merge/127604
Your team Zorba Coders is subscribed to branch lp:zorba.

-- 
Mailing list: https://launchpad.net/~zorba-coders
Post to : zorba-coders@lists.launchpad.net
Unsubscribe : https://launchpad.net/~zorba-coders
More help   : https://help.launchpad.net/ListHelp


[Zorba-coders] [Merge] lp:~zorba-coders/zorba/system_doc into lp:zorba/system-module

2012-10-02 Thread Matthias Brantner
The proposal to merge lp:~zorba-coders/zorba/system_doc into 
lp:zorba/system-module has been updated.

Status: Needs review = Approved

For more details, see:
https://code.launchpad.net/~zorba-coders/zorba/system_doc/+merge/126740
-- 
https://code.launchpad.net/~zorba-coders/zorba/system_doc/+merge/126740
Your team Zorba Coders is subscribed to branch lp:zorba/system-module.

-- 
Mailing list: https://launchpad.net/~zorba-coders
Post to : zorba-coders@lists.launchpad.net
Unsubscribe : https://launchpad.net/~zorba-coders
More help   : https://help.launchpad.net/ListHelp


[Zorba-coders] [Merge] lp:~zorba-coders/zorba/system_doc into lp:zorba/system-module

2012-10-02 Thread Zorba Build Bot
Validation queue starting for merge proposal.
Log at: 
http://zorbatest.lambda.nu:8080/remotequeue/system_doc-2012-10-03T00-14-39.319Z/log.html
-- 
https://code.launchpad.net/~zorba-coders/zorba/system_doc/+merge/126740
Your team Zorba Coders is subscribed to branch lp:zorba/system-module.

-- 
Mailing list: https://launchpad.net/~zorba-coders
Post to : zorba-coders@lists.launchpad.net
Unsubscribe : https://launchpad.net/~zorba-coders
More help   : https://help.launchpad.net/ListHelp


[Zorba-coders] [Merge] lp:~zorba-coders/zorba/system_doc into lp:zorba/system-module

2012-10-02 Thread noreply
The proposal to merge lp:~zorba-coders/zorba/system_doc into 
lp:zorba/system-module has been updated.

Status: Approved = Merged

For more details, see:
https://code.launchpad.net/~zorba-coders/zorba/system_doc/+merge/126740
-- 
https://code.launchpad.net/~zorba-coders/zorba/system_doc/+merge/126740
Your team Zorba Coders is subscribed to branch lp:zorba/system-module.

-- 
Mailing list: https://launchpad.net/~zorba-coders
Post to : zorba-coders@lists.launchpad.net
Unsubscribe : https://launchpad.net/~zorba-coders
More help   : https://help.launchpad.net/ListHelp


[Zorba-coders] [Merge] lp:~zorba-coders/zorba/xqxq-bug-1056704 into lp:zorba/xqxq-module

2012-10-02 Thread Sorin Marian Nasoi
The proposal to merge lp:~zorba-coders/zorba/xqxq-bug-1056704 into 
lp:zorba/xqxq-module has been updated.

Commit Message changed to:

Replaced xqxq's implementation of uuid for zorba's implementation in 
zorba/util/uuid.h

For more details, see:
https://code.launchpad.net/~zorba-coders/zorba/xqxq-bug-1056704/+merge/127594
-- 
https://code.launchpad.net/~zorba-coders/zorba/xqxq-bug-1056704/+merge/127594
Your team Zorba Coders is subscribed to branch lp:zorba/xqxq-module.

-- 
Mailing list: https://launchpad.net/~zorba-coders
Post to : zorba-coders@lists.launchpad.net
Unsubscribe : https://launchpad.net/~zorba-coders
More help   : https://help.launchpad.net/ListHelp


[Zorba-coders] [Merge] lp:~zorba-coders/zorba/xqxq-bug-1056704 into lp:zorba/xqxq-module

2012-10-02 Thread Zorba Build Bot
Validation queue starting for merge proposal.
Log at: 
http://zorbatest.lambda.nu:8080/remotequeue/xqxq-bug-1056704-2012-10-03T02-14-38.686Z/log.html
-- 
https://code.launchpad.net/~zorba-coders/zorba/xqxq-bug-1056704/+merge/127594
Your team Zorba Coders is subscribed to branch lp:zorba/xqxq-module.

-- 
Mailing list: https://launchpad.net/~zorba-coders
Post to : zorba-coders@lists.launchpad.net
Unsubscribe : https://launchpad.net/~zorba-coders
More help   : https://help.launchpad.net/ListHelp


Re: [Zorba-coders] [Merge] lp:~zorba-coders/zorba/xqxq-bug-1056704 into lp:zorba/xqxq-module

2012-10-02 Thread Zorba Build Bot
The attempt to merge lp:~zorba-coders/zorba/xqxq-bug-1056704 into 
lp:zorba/xqxq-module failed. Below is the output from the failed tests.


CMake Error at /home/ceej/zo/testing/zorbatest/tester/TarmacLander.cmake:274 
(message):
  Validation queue job xqxq-bug-1056704-2012-10-03T02-14-38.686Z is finished.
  The final status was:

  

  1 tests did not succeed - changes not commited.


Error in read script: /home/ceej/zo/testing/zorbatest/tester/TarmacLander.cmake

-- 
https://code.launchpad.net/~zorba-coders/zorba/xqxq-bug-1056704/+merge/127594
Your team Zorba Coders is subscribed to branch lp:zorba/xqxq-module.

-- 
Mailing list: https://launchpad.net/~zorba-coders
Post to : zorba-coders@lists.launchpad.net
Unsubscribe : https://launchpad.net/~zorba-coders
More help   : https://help.launchpad.net/ListHelp


[Zorba-coders] [Merge] lp:~zorba-coders/zorba/xqxq-bug-1056704 into lp:zorba/xqxq-module

2012-10-02 Thread Zorba Build Bot
The proposal to merge lp:~zorba-coders/zorba/xqxq-bug-1056704 into 
lp:zorba/xqxq-module has been updated.

Status: Approved = Needs review

For more details, see:
https://code.launchpad.net/~zorba-coders/zorba/xqxq-bug-1056704/+merge/127594
-- 
https://code.launchpad.net/~zorba-coders/zorba/xqxq-bug-1056704/+merge/127594
Your team Zorba Coders is subscribed to branch lp:zorba/xqxq-module.

-- 
Mailing list: https://launchpad.net/~zorba-coders
Post to : zorba-coders@lists.launchpad.net
Unsubscribe : https://launchpad.net/~zorba-coders
More help   : https://help.launchpad.net/ListHelp